diff --git a/.gitignore b/.gitignore
index 58a0408..e11f42d 100644
--- a/.gitignore
+++ b/.gitignore
@@ -44,4 +44,3 @@ SilentDragonLite
.gdb_history
.*sw?
core
-*.qm
diff --git a/res/silentdragonxlite_be.ts b/res/silentdragonxlite_be.ts
index 98459e3..8cb14f1 100644
--- a/res/silentdragonxlite_be.ts
+++ b/res/silentdragonxlite_be.ts
@@ -761,7 +761,7 @@ p, li { white-space: pre-wrap; }
Pay drgx &URI...
- Заплаціць hush &URI...
+ Заплаціць drgx &URI...Connect mobile &app
@@ -779,7 +779,7 @@ p, li { white-space: pre-wrap; }
Request drgx...
- Запытаць hush...
+ Запытаць drgx...
@@ -805,17 +805,17 @@ p, li { white-space: pre-wrap; }
Paste DRGX URI
- Уставіць HUSH URI
+ Уставіць DRGX URIError paying DRGX URI
- Памылка аплаты HUSH URI
+ Памылка аплаты DRGX URIURI should be of the form 'drgx:<addr>?amt=x&memo=y
- URI павінна мець форму 'hush:<addr>?amt=x&memo=y
+ URI павінна мець форму 'drgx:<addr>?amt=x&memo=y
@@ -1432,7 +1432,7 @@ Note: Funds need 1 confirmations before they can be spent
%1 doesn't seem to be a valid dragonx address.
- %1 здаецца гэта несапраўдны hush-адрас.
+ %1 здаецца гэта несапраўдны drgx-адрас.
@@ -1626,7 +1626,7 @@ Would you like to visit the releases page?
No dragonx price was available to convert from USD
- Няма hush цаны да канвертацыі з USD
+ Няма drgx цаны да канвертацыі з USD
@@ -1943,17 +1943,17 @@ Would you like to visit the releases page?
Request payment from a Sapling address. You'll send a dragonx 0.0001 transaction to the address with a dragonx payment URI. The memo will be included in the transaction when the address pays you.
- Запытайце плацёж з Sapling адраса. Вы адправіце 0.0001 hush з выкарыстаннем URI аплаты. Нататка будзе ўключана ў транзакцыю калі вам заплацяць.
+ Запытайце плацёж з Sapling адраса. Вы адправіце 0.0001 drgx з выкарыстаннем URI аплаты. Нататка будзе ўключана ў транзакцыю калі вам заплацяць.Error paying DRGX URI
- Памылка аплаты hush URI
+ Памылка аплаты drgx URIURI should be of the form 'drgx:<addr>?amt=x&memo=y
- URI павінна мець форму 'hush:<addr>?amt=x&memo=y
+ URI павінна мець форму 'drgx:<addr>?amt=x&memo=y
@@ -2151,7 +2151,7 @@ Would you like to visit the releases page?
Connect to the internet to Fetch dragonx prices
- Падключыцеся да Інтэрнэту, каб даведацца пра цэну hush
+ Падключыцеся да Інтэрнэту, каб даведацца пра цэну drgx
@@ -2166,7 +2166,7 @@ Would you like to visit the releases page?
Fetch dragonx prices
- Выберыце hush цэны
+ Выберыце drgx цэны
@@ -2389,12 +2389,12 @@ Would you like to visit the releases page?
Configure dragonx.conf
- Наладзиць hush.conf
+ Наладзиць dragonx.confYour dragonx node will be configured for you automatically
- Ваш hush-вузел будзе наладжаны для вас аўтаматычна
+ Ваш drgx-вузел будзе наладжаны для вас аўтаматычна
@@ -2404,7 +2404,7 @@ Would you like to visit the releases page?
Allow connections to the internet to check for updates, get dragonx prices etc...
- Дазволіць злучэння з Інтэрнэтам дабы правяраць наяўнасць абнаўленняў, атрымліваць hush і гэтак далей...
+ Дазволіць злучэння з Інтэрнэтам дабы правяраць наяўнасць абнаўленняў, атрымліваць drgx і гэтак далей...
@@ -2464,7 +2464,7 @@ p, li { white-space: pre-wrap; }
<html><head/><body><p align="center"><span style=" text-decoration: underline;">Your DragonX Address </span></p></body></html>
- <html><head/><body><p align="center"><span style=" text-decoration: underline;">Ваш hush Адрас </span></p></body></html>
+ <html><head/><body><p align="center"><span style=" text-decoration: underline;">Ваш DragonX Адрас </span></p></body></html>
diff --git a/res/silentdragonxlite_de.ts b/res/silentdragonxlite_de.ts
index f3cd55b..3539f7d 100644
--- a/res/silentdragonxlite_de.ts
+++ b/res/silentdragonxlite_de.ts
@@ -902,12 +902,12 @@ p, li { white-space: pre-wrap; }
Paste DRGX URI
- Hush URI einfügen
+ DRGX URI einfügenError paying DRGX URI
- Fehler bei HUSH URI
+ Fehler bei DRGX URI
@@ -2181,17 +2181,17 @@ Möchten Sie die Release Seite besuchen?
Request payment from a Sapling address. You'll send a dragonx 0.0001 transaction to the address with a dragonx payment URI. The memo will be included in the transaction when the address pays you.
- Bezahlung über eine sichere Adresse anfordern. Sende 0.0001 HUSH an die Adresse der Zahlungsanfrage, mit einer HUSH bezahl URI. Die Nachricht wird zur Transaktion hinzugefügt, sobald bezahlt wird.
+ Bezahlung über eine sichere Adresse anfordern. Sende 0.0001 DRGX an die Adresse der Zahlungsanfrage, mit einer DRGX bezahl URI. Die Nachricht wird zur Transaktion hinzugefügt, sobald bezahlt wird.Error paying DRGX URI
- Fehler bezahl HUSH URI
+ Fehler bezahl DRGX URIURI should be of the form 'drgx:<addr>?amt=x&memo=y
- Die URI sollte im folgendem Format sein: 'hush:<Adresse>?Betrag=x&Nachricht=y
+ Die URI sollte im folgendem Format sein: 'drgx:<Adresse>?Betrag=x&Nachricht=y
@@ -2678,8 +2678,8 @@ Möchten Sie die Release Seite besuchen?
createhushConf
- Configure dragonx.conf
- Konfiguriere HUSH3.conf
+ Configure DRAGONX.conf
+ Konfiguriere DRAGONX.conf
@@ -2851,7 +2851,7 @@ li.checked::marker { content: "\2612"; }
Request payment from a Sapling address. You'll send a dragonx 0.0001 transaction to the address with a dragonx payment URI. The memo will be included in the transaction when the address pays you.
- Bezahlung über eine sichere Adresse anfordern. Sende 0.0001 HUSH an die Adresse der Zahlungsanfrage, mit einer HUSH bezahl URI. Die Nachricht wird zur Transaktion hinzugefügt, sobald bezahlt wird.
+ Bezahlung über eine sichere Adresse anfordern. Sende 0.0001 DRGX an die Adresse der Zahlungsanfrage, mit einer DRGX bezahl URI. Die Nachricht wird zur Transaktion hinzugefügt, sobald bezahlt wird.
diff --git a/res/silentdragonxlite_es.ts b/res/silentdragonxlite_es.ts
index 34ab068..37309aa 100644
--- a/res/silentdragonxlite_es.ts
+++ b/res/silentdragonxlite_es.ts
@@ -864,17 +864,17 @@ p, li { white-space: pre-wrap; }
Paste DRGX URI
- Pegar URI HUSH
+ Pegar URI DRGXError paying DRGX URI
- Error al pagar HUSH URI
+ Error al pagar DRGX URIURI should be of the form 'drgx:<addr>?amt=x&memo=y
- URI debe tener la forma 'Hush:<Direct>?amt=x¬a=y
+ URI debe tener la forma 'drgx:<Direct>?amt=x¬a=y
diff --git a/res/silentdragonxlite_fa.ts b/res/silentdragonxlite_fa.ts
index 8dbce7f..c20c33b 100644
--- a/res/silentdragonxlite_fa.ts
+++ b/res/silentdragonxlite_fa.ts
@@ -970,12 +970,12 @@ Please use 'Remove Wallet Encryption' if you want to remove the wallet
Paste DRGX URI
- Hush URI چسبانیدن
+ DRGX URI چسبانیدن Error paying DRGX URI
- HUSH URI خطا در پرداخت
+ DRGX URI خطا در پرداخت
diff --git a/res/silentdragonxlite_hr.ts b/res/silentdragonxlite_hr.ts
index a35cb5b..85ab36a 100644
--- a/res/silentdragonxlite_hr.ts
+++ b/res/silentdragonxlite_hr.ts
@@ -963,12 +963,12 @@ Molimo koristite 'Uklonite šifriranje novčanika' ako želite uklonit
Paste DRGX URI
- Zalijepi HUSH URI
+ Zalijepi DRGX URIError paying DRGX URI
- Greška u plaćanju HUSH URI
+ Greška u plaćanju DRGX URI
diff --git a/res/silentdragonxlite_nl.ts b/res/silentdragonxlite_nl.ts
index c5cae86..c3278d8 100644
--- a/res/silentdragonxlite_nl.ts
+++ b/res/silentdragonxlite_nl.ts
@@ -1937,17 +1937,17 @@ Wilt u de releasepagina bezoeken?
Request payment from a Sapling address. You'll send a dragonx 0.0001 transaction to the address with a dragonx payment URI. The memo will be included in the transaction when the address pays you.
- Betaling van een verborgen Sapling adres aanvragen. U stuurt een HUSH 0.0001 transactie naar het adres met een HUSH betaling-URI. Het onderstaande bericht zal toegevoegd worden aan de transactie als het adres u betaalt.
+ Betaling van een verborgen Sapling adres aanvragen. U stuurt een DRGX 0.0001 transactie naar het adres met een DRGX betaling-URI. Het onderstaande bericht zal toegevoegd worden aan de transactie als het adres u betaalt.Error paying DRGX URI
- Fout bij betaling HUSH URI
+ Fout bij betaling DRGX URIURI should be of the form 'drgx:<addr>?amt=x&memo=y
- De URI moet in het volgende formaat zijn: 'hush:<adres>?amt=x&memo=y'
+ De URI moet in het volgende formaat zijn: 'drgx:<adres>?amt=x&memo=y'
@@ -2539,7 +2539,7 @@ li.checked::marker { content: "\2612"; }
Request payment from a Sapling address. You'll send a dragonx 0.0001 transaction to the address with a dragonx payment URI. The memo will be included in the transaction when the address pays you.
- Betalingsverzoek vanuit een Sapling adres. U stuurt een HUSH 0.0001 transactiue naar het adres met een Hush betaling-URI. Het bericht zal worden meegenomen in de transactie wanneer het adres u betaalt.
+ Betalingsverzoek vanuit een Sapling adres. U stuurt een DRGX 0.0001 transactiue naar het adres met een DRGX betaling-URI. Het bericht zal worden meegenomen in de transactie wanneer het adres u betaalt.
diff --git a/res/silentdragonxlite_pl.ts b/res/silentdragonxlite_pl.ts
index f42173e..19ff2e4 100644
--- a/res/silentdragonxlite_pl.ts
+++ b/res/silentdragonxlite_pl.ts
@@ -148,7 +148,7 @@ p, li { white-space: pre-wrap; }
</style></head><body style=" font-family:'Ubuntu'; font-size:11pt; font-weight:400; font-style:normal;">
<h1 align="center" style=" margin-top:18px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:xx-large; font-weight:600;">Hush + HushChat Warunki świadczenia Usług</span></h1>
<p style=" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">Wszyscy użytkownicy tej platformy zgadzają się nie używać jej do inicjowania lub groźby jakiejkolwiek gwałtownej ingerencji lub przemocy wobec osoby lub jej mienia, znany jako, <a href="https://en.wikipedia.org/wiki/Non-aggression_principle"><span style=" text-decoration: underline; color:#0000ff;">Zasada Nieagresji</span></a>.</p>
-<p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">USŁUGA JEST ŚWIADCZONA „W STANIE, W JAKIM JEST”, A PROGRAMIŚCI SERWISU HUSH NIE SKŁADAJĄ ŻADNYCH KONKRETNYCH ZOBOWIĄZAŃ ANI GRAŹNYCH GRAŹNYCH DOTYCZĄCYCH USŁUGI.</p>
+<p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">USŁUGA JEST ŚWIADCZONA „W STANIE, W JAKIM JEST”, A PROGRAMIŚCI SERWISU D NIE SKŁADAJĄ ŻADNYCH KONKRETNYCH ZOBOWIĄZAŃ ANI GRAŹNYCH GRAŹNYCH DOTYCZĄCYCH USŁUGI.</p>
<p style="-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><br /></p>
<p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">Klikając przycisk OK, wyracasz zgodę na używanie portfeli Hush, SilentDragon i innych portfeli, HushChat i jakiegokolwiek oprogramowania opracowanego przez programistów Hush zgodnie z lokalnymi przepisami, że wszystkie zobowiązania związane z korzystaniem z tej usługi są Twoje, a programiści Hush NIE BĘDĄ ODPOWIEDZIALNI ZA jakiekolwiek straty związane z korzystaniem z tego oprogramowania.</p>
<p style="-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><br /></p>
@@ -805,12 +805,12 @@ p, li { white-space: pre-wrap; }
Paste DRGX URI
- Wklej HUSH URI
+ Wklej DRGX URIError paying DRGX URI
- Błąd płatności HUSH URI
+ Błąd płatności DRGX URI
diff --git a/res/silentdragonxlite_pt.ts b/res/silentdragonxlite_pt.ts
index e619248..d933ad0 100644
--- a/res/silentdragonxlite_pt.ts
+++ b/res/silentdragonxlite_pt.ts
@@ -1279,12 +1279,12 @@ Por favor usa 'Desencriptar carteira' se quiser remover a encriptaçã
Paste DRGX URI
- Colar URI HUSH
+ Colar URI DRGXError paying DRGX URI
- Erro ao pagar HUSH URI
+ Erro ao pagar DRGX URI
diff --git a/res/silentdragonxlite_ro.ts b/res/silentdragonxlite_ro.ts
index 1ce9a84..4c27440 100644
--- a/res/silentdragonxlite_ro.ts
+++ b/res/silentdragonxlite_ro.ts
@@ -781,7 +781,7 @@ p, li { white-space: pre-wrap; }
Pay drgx &URI...
- Plateste HUSH &URI...
+ Plateste DRGX &URI...
@@ -801,7 +801,7 @@ p, li { white-space: pre-wrap; }
Request drgx...
- Solicita HUSH...
+ Solicita DRGX...
@@ -1019,12 +1019,12 @@ Rugam sa folositi 'Eliminati Criptarea Portofelului' daca doriti sa el
Paste DRGX URI
- Lipeste HUSH URI
+ Lipeste DRGX URIError paying DRGX URI
- Eroarea platii HUSH URI
+ Eroarea platii DRGX URI
@@ -1570,7 +1570,7 @@ Nota: Fondurile au nevoie de 5 confirmatii inainte ca sa fiu transmise
%1 doesn't seem to be a valid dragonx address.
- nu este o adresa HUSH valida
+ nu este o adresa DRGX valida
@@ -2096,12 +2096,12 @@ Doriti sa vizitati pagina veriunii?
Request payment from a Sapling address. You'll send a dragonx 0.0001 transaction to the address with a dragonx payment URI. The memo will be included in the transaction when the address pays you.
- Solicita plata de pe Sapling adresa. HUSH 0.0001 tranzactia va fi transmisa la adresa cu plata HUSH URI. Memo va fi inclus in tranzactie cind adresa va plati.
+ Solicita plata de pe Sapling adresa. dragonx 0.0001 tranzactia va fi transmisa la adresa cu plata dragonx URI. Memo va fi inclus in tranzactie cind adresa va plati.Error paying DRGX URI
- Eroare platii HUSH URI
+ Eroare platii DRGX URI
@@ -2348,7 +2348,7 @@ Doriti sa vizitati pagina veriunii?
Connect to the internet to Fetch dragonx prices
- Conectati la internet pentru a vedea pretul HUSH
+ Conectati la internet pentru a vedea pretul DRGX
@@ -2752,7 +2752,7 @@ p, li { white-space: pre-wrap; }
Request payment from a Sapling address. You'll send a dragonx 0.0001 transaction to the address with a dragonx payment URI. The memo will be included in the transaction when the address pays you.
- Solicita plata de pe Sapling adresa. HUSH 0.0001 tranzactia va fi transmisa la adresa cu plata HUSH URI. Memo va fi inclus in tranzactie cind adresa va plati.
+ Solicita plata de pe Sapling adresa. dragonx 0.0001 tranzactia va fi transmisa la adresa cu plata dragonx URI. Memo va fi inclus in tranzactie cind adresa va plati.
diff --git a/res/silentdragonxlite_ru.ts b/res/silentdragonxlite_ru.ts
index ed758df..25229eb 100644
--- a/res/silentdragonxlite_ru.ts
+++ b/res/silentdragonxlite_ru.ts
@@ -1017,12 +1017,12 @@ p, li { white-space: pre-wrap; }
Paste DRGX URI
- Вставить HUSH URI
+ Вставить DRGX URIError paying DRGX URI
- Ошибка при оплате HUSH URI
+ Ошибка при оплате DRGX URI
diff --git a/res/silentdragonxlite_sr.ts b/res/silentdragonxlite_sr.ts
index ba811fb..2c5f150 100644
--- a/res/silentdragonxlite_sr.ts
+++ b/res/silentdragonxlite_sr.ts
@@ -963,12 +963,12 @@ Molimo koristite 'Uklonite šifrovanje novčanika' ako želite uklonit
Paste DRGX URI
- Zalepi HUSH URI
+ Zalepi DRGX URIError paying DRGX URI
- Greška u plaćanju HUSH URI
+ Greška u plaćanju DRGX URI
diff --git a/res/silentdragonxlite_ud.ts b/res/silentdragonxlite_ud.ts
index b3f0095..621c8b6 100644
--- a/res/silentdragonxlite_ud.ts
+++ b/res/silentdragonxlite_ud.ts
@@ -1008,12 +1008,12 @@ Please use 'Remove Wallet Encryption' if you want to remove the wallet
Paste DRGX URI
- HUSH URI پیسٹ کریں
+ DRGX URI پیسٹ کریںError paying DRGX URI
- عرر ہے HUSH URI کی ادائیگی میں
+ عرر ہے DRGX URI کی ادائیگی میں
diff --git a/src/firsttimewizard.cpp b/src/firsttimewizard.cpp
index 701d717..c2009e3 100644
--- a/src/firsttimewizard.cpp
+++ b/src/firsttimewizard.cpp
@@ -171,7 +171,7 @@ NewOrRestorePage::NewOrRestorePage(FirstTimeWizard *parent) : QWizardPage(parent
auto fnPasswordEdited = [=](const QString&) {
// Enable the Finish button if the passwords match.
QString passphraseBlank = form.txtPassword->text();
- QString passphrase = QString("HUSH3") + passphraseBlank + QString("SDL");
+ QString passphrase = QString("DRGX") + passphraseBlank + QString("SDXL");
if (!form.txtPassword->text().isEmpty() &&
form.txtPassword->text() == form.txtConfirmPassword->text() && passphraseBlank.size() >= 16 ){
diff --git a/src/mainwindow.cpp b/src/mainwindow.cpp
index 1d4564d..bc3a664 100644
--- a/src/mainwindow.cpp
+++ b/src/mainwindow.cpp
@@ -467,7 +467,7 @@ void MainWindow::encryptWallet() {
{
QString passphraseBlank = ed.txtPassword->text(); // data comes from user inputs
- QString passphrase = QString("HUSH3") + passphraseBlank + QString("SDL");
+ QString passphrase = QString("DRGX") + passphraseBlank + QString("SDXL");
int length = passphrase.length();
@@ -563,7 +563,7 @@ void MainWindow::removeWalletEncryption() {
if (d.exec() == QDialog::Accepted) {
QString passphraseBlank = ed.txtPassword->text(); // data comes from user inputs
- QString passphrase = QString("HUSH3") + passphraseBlank + QString("SDL");
+ QString passphrase = QString("DRGX") + passphraseBlank + QString("SDXL");
int length = passphrase.length();
@@ -647,7 +647,7 @@ void MainWindow::removeWalletEncryptionStartUp() {
if (d.exec() == QDialog::Accepted){
QString passphraseBlank = ed.txtPassword->text(); // data comes from user inputs
- QString passphrase = QString("HUSH3") + passphraseBlank + QString("SDL");
+ QString passphrase = QString("DRGX") + passphraseBlank + QString("SDXL");
int length = passphrase.length();
char *sequence = NULL;
@@ -1014,7 +1014,7 @@ void MainWindow::payhushURI(QString uri, QString myAddr) {
// If there was no URI passed, ask the user for one.
if (uri.isEmpty()) {
uri = QInputDialog::getText(this, tr("Paste DRGX URI"),
- "HUSH URI" + QString(" ").repeated(180));
+ "DRGX URI" + QString(" ").repeated(180));
}
// If there's no URI, just exit
@@ -1869,7 +1869,7 @@ Tx MainWindow::createTxFromSendChatPage() {
QString moneymemo = this->getMoneyMemo();
/////////User input for chatmemos
- QString memoplain = QString("Money transaction of : ") + amtStr + QString(" HUSH") + QString("\n") + QString("\n") + moneymemo;
+ QString memoplain = QString("Money transaction of : ") + amtStr + QString(" DRGX") + QString("\n") + QString("\n") + moneymemo;
/////////We convert the user input from QString to unsigned char*, so we can encrypt it later
int lengthmemo = memoplain.length();
@@ -2157,7 +2157,7 @@ Tx MainWindow::createTxFromSendRequestChatPage() {
QString moneymemo = this->getMoneyMemo();
/////////User input for chatmemos
- QString memoplain = QString("Request of : ") + amtStr + QString(" HUSH ") + QString("\n") + QString("\n") + moneymemo;
+ QString memoplain = QString("Request of : ") + amtStr + QString(" DRGX ") + QString("\n") + QString("\n") + moneymemo;
/////////We convert the user input from QString to unsigned char*, so we can encrypt it later
int lengthmemo = memoplain.length();
diff --git a/src/settings.cpp b/src/settings.cpp
index 3dc5b11..858a3ba 100644
--- a/src/settings.cpp
+++ b/src/settings.cpp
@@ -133,7 +133,7 @@ bool Settings::isSaplingActive() {
}
double Settings::getDRAGONXPrice() {
- return HUSHPrice;
+ return DRAGONXPrice;
}
double Settings::getEURPrice() {
return EURPrice;
@@ -358,7 +358,7 @@ QString Settings::getTokenName() {
if (Settings::getInstance()->isTestnet()) {
return "TUSH";
} else {
- return "HUSH";
+ return "DRAGONX";
}
}
@@ -395,8 +395,8 @@ QString Settings::paymentURIPretty(PaymentURI uri) {
PaymentURI Settings::parseURI(QString uri) {
PaymentURI ans;
- if (!uri.startsWith("hush:")) {
- ans.error = "Not a HUSH payment URI";
+ if (!uri.startsWith("drgx:")) {
+ ans.error = "Not a DRGX payment URI";
return ans;
}
diff --git a/src/settings.h b/src/settings.h
index 4ead686..cfc1578 100644
--- a/src/settings.h
+++ b/src/settings.h
@@ -81,7 +81,7 @@ public:
bool isSaplingActive();
- void setDRAGONXPrice(double p) { HUSHPrice = p; }
+ void setDRAGONXPrice(double p) { DRGXPrice = p; }
void setEURPrice(double p) { EURPrice = p; }
void setBTCPrice(double p) { BTCPrice = p; }
void setCNYPrice(double p) { CNYPrice = p; }
@@ -200,7 +200,7 @@ private:
bool _useEmbedded = false;
bool _headless = false;
- double HUSHPrice = 0.0;
+ double DRGXPrice = 0.0;
double BTCPrice = 0.0;
double EURPrice = 0.0;
double CNYPrice = 0.0;
diff --git a/util/SilentDragonLite.desktop b/util/SilentDragonLite.desktop
index 7606017..292b979 100644
--- a/util/SilentDragonLite.desktop
+++ b/util/SilentDragonLite.desktop
@@ -1,7 +1,7 @@
[Desktop Entry]
Version=1.0
Name=SilentDragonXLite
-Comment=Lite wallet for HUSH cryptocurrency
+Comment=Lite wallet for DragonX cryptocurrency
Exec=/home/user/SilentDragonXLite/SilentDragonXLite
Icon=/home/user/SilentDragonXLite/res/SDLogo.png
Terminal=false
diff --git a/res/silentdragonxlite_id.ts b/res/silentdragonxlite_id.ts
index d7d7ce6..49721c7 100644
--- a/res/silentdragonxlite_id.ts
+++ b/res/silentdragonxlite_id.ts
@@ -1024,7 +1024,7 @@ Mohon Gunakan 'Hapus Enkripsi Dompet' Jika anda ingin menghapus Enkrip
Error paying DRGX URI
- Error membayar HUSH URI
+ Error membayar DRGX URI
@@ -1577,7 +1577,7 @@ Note: Dana membutuhkan 5 konfirmasi sebelum mereka bisa digunakan
%1 doesn't seem to be a valid dragonx address.
%1 doesn't kelihatannya bukan Alamat HUSH yang valid
@@ -1577,7 +1577,7 @@ Note: Dana membutuhkan 5 konfirmasi sebelum mereka bisa digunakan
%1 doesn't seem to be a valid dragonx address.
- %1 doesn't kelihatannya bukan Alamat HUSH yang valid
+ %1 doesn't kelihatannya bukan Alamat DRGX yang valid